==> mobroute-0.8.4.tar.gz: mobroute-v0.8.4/csa_test/transferpossible_test.go <==
package csa_test

import (
	"git.sr.ht/~mil/mobroute/csa"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utillog"
	"testing"
)

type TransferPossibleBetweenConnectionsTestCaseArgs struct {
	TransfersMap       map[string]map[string]uint
	FromConnection     *dbt.Connection
	ToConnection       *dbt.Connection
	MaxTransferSeconds uint
}

type TransferPossibleBetweenConnectionsTestCase struct {
	Test   string
	Args   TransferPossibleBetweenConnectionsTestCaseArgs
	Expect bool
}

func Test_TransferPossibleBetweenConnections(t *testing.T) {
	utillog.LogWarn = true

	var (
		testCases = []TransferPossibleBetweenConnectionsTestCase{
			{
				Test: "False if the from connection's TripID == to connection's TripID",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap:       map[string]map[string]uint{},
					FromConnection:     &dbt.Connection{TripID: "tripfoo"},
					ToConnection:       &dbt.Connection{TripID: "tripfoo"},
					MaxTransferSeconds: 10,
				},
				Expect: false,
			},
			{
				Test: "False if SIDUs mismatch, and transfer not defined",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap:       map[string]map[string]uint{},
					FromConnection:     &dbt.Connection{TripID: "tripfoo", ToSSIDU: "foo", ToST: 7},
					ToConnection:       &dbt.Connection{TripID: "tripbar", FromSSIDU: "bar", FromST: 12},
					MaxTransferSeconds: 10,
				},
				Expect: false,
			},
			{
				Test: "True if SIDUs mismatch, transfer defined & lt max",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap: map[string]map[string]uint{
						"foo": map[string]uint{"bar": 2},
					},
					FromConnection:     &dbt.Connection{TripID: "tripfoo", ToSSIDU: "foo", ToST: 7},
					ToConnection:       &dbt.Connection{TripID: "tripbar", FromSSIDU: "bar", FromST: 12},
					MaxTransferSeconds: 10,
				},
				Expect: true,
			},
			{
				Test: "False if SIDUs mismatch, transfer defined & gt max",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap: map[string]map[string]uint{
						"foo": map[string]uint{"bar": 11},
					},
					FromConnection:     &dbt.Connection{TripID: "tripfoo", ToSSIDU: "foo", ToST: 2},
					ToConnection:       &dbt.Connection{TripID: "tripbar", FromSSIDU: "bar", FromST: 9},
					MaxTransferSeconds: 10,
				},
				Expect: false,
			},
		}
	)

	for _, testCase := range testCases {
		result := csa.TransferPossibleBetweenConnections(
			testCase.Args.TransfersMap,
			testCase.Args.FromConnection,
			testCase.Args.ToConnection,
			testCase.Args.MaxTransferSeconds,
		)
		if result != testCase.Expect {
			t.Fatalf("For (%v): Want %v; got %v", testCase.Test, testCase.Expect, result)
		}
	}
}

==> mobroute-0.9.0.tar.gz: mobroute-v0.9.0/csa_test/transferpossible_test.go <==
package csa_test

import (
	"git.sr.ht/~mil/mobroute/csa"
	"git.sr.ht/~mil/mobroute/dbt"
	"git.sr.ht/~mil/mobroute/util/utillog"
	"testing"
)

type TransferPossibleBetweenConnectionsTestCaseArgs struct {
	TransfersMap       map[string]map[string]uint
	FromConnection     *dbt.Connection
	ToConnection       *dbt.Connection
	MaxTransferSeconds uint
}

type TransferPossibleBetweenConnectionsTestCase struct {
	Test   string
	Args   TransferPossibleBetweenConnectionsTestCaseArgs
	Expect bool
}

func Test_TransferPossibleBetweenConnections(t *testing.T) {
	utillog.LogWarn = true

	var (
		testCases = []TransferPossibleBetweenConnectionsTestCase{
			{
				Test: "False if the from connection's TripID == to connection's TripID",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap:       map[string]map[string]uint{},
					FromConnection:     &dbt.Connection{TripID: "tripfoo"},
					ToConnection:       &dbt.Connection{TripID: "tripfoo"},
					MaxTransferSeconds: 10,
				},
				Expect: false,
			},
			{
				Test: "False if stop UIDs mismatch, and transfer not defined",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap:       map[string]map[string]uint{},
					FromConnection:     &dbt.Connection{TripID: "tripfoo", ToStopUID: "foo", ToST: 7},
					ToConnection:       &dbt.Connection{TripID: "tripbar", FromStopUID: "bar", FromST: 12},
					MaxTransferSeconds: 10,
				},
				Expect: false,
			},
			{
				Test: "True if stop UIDs mismatch, transfer defined & lt max",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap: map[string]map[string]uint{
						"foo": map[string]uint{"bar": 2},
					},
					FromConnection:     &dbt.Connection{TripID: "tripfoo", ToStopUID: "foo", ToST: 7},
					ToConnection:       &dbt.Connection{TripID: "tripbar", FromStopUID: "bar", FromST: 12},
					MaxTransferSeconds: 10,
				},
				Expect: true,
			},
			{
				Test: "False if Stop UIDs mismatch, transfer defined & gt max",
				Args: TransferPossibleBetweenConnectionsTestCaseArgs{
					TransfersMap: map[string]map[string]uint{
						"foo": map[string]uint{"bar": 11},
					},
					FromConnection:     &dbt.Connection{TripID: "tripfoo", ToStopUID: "foo", ToST: 2},
					ToConnection:       &dbt.Connection{TripID: "tripbar", FromStopUID: "bar", FromST: 9},
					MaxTransferSeconds: 10,
				},
				Expect: false,
			},
		}
	)

	for _, testCase := range testCases {
		result := csa.TransferPossibleBetweenConnections(
			testCase.Args.TransfersMap,
			testCase.Args.FromConnection,
			testCase.Args.ToConnection,
			testCase.Args.MaxTransferSeconds,
		)
		if result != testCase.Expect {
			t.Fatalf("For (%v): Want %v; got %v", testCase.Test, testCase.Expect, result)
		}
	}
}
